# eric7.WebBrowser.UrlBar.UrlBar

Module implementing the URL bar widget.

### Global Attributes

None

### Classes

UrlBar | Class implementing a line edit for entering URLs.

### Functions

None

## UrlBar

Class implementing a line edit for entering URLs.

### Derived from

EricClearableLineEdit

### Class Attributes

None

### Class Methods

None

### Methods

UrlBar | Constructor
__bookmarkChanged | Private slot to handle bookmark or speed dial changes.
__browserUrlChanged | Private slot to handle a URL change of the associated browser.
__checkBookmark | Private slot to check the current URL for the bookmarked state.
__loadFinished | Private slot to set some data after the page was loaded.
__loadProgress | Private slot to track the load progress.
__loadStarted | Private slot to perform actions before the page is loaded.
__rssTriggered | Private slot to handle clicking the RSS icon.
__setRssButton | Private slot to show the RSS button.
__showBookmarkInfo | Private slot to show a dialog with some bookmark info.
__showThreatInfo | Private slot to show the threat info widget.
__sslConfigurationChanged | Private slot to handle a change of the associated web page SSL configuration.
browser | Public method to get the associated browser.
dragEnterEvent | Protected method to handle drag enter events.
dropEvent | Protected method to handle drop events.
focusOutEvent | Protected method to handle focus out event.
keyPressEvent | Protected method to handle key presses.
mouseDoubleClickEvent | Protected method to handle mouse double click events.
mousePressEvent | Protected method called by a mouse press event.
preferencesChanged | Public slot to handle a change of preferences.
setBrowser | Public method to set the browser connection.

### Static Methods

None

#### UrlBar (Constructor)

UrlBar(mainWindow, parent=None)

Constructor

mainWindow (WebBrowserWindow)
  reference to the main window
parent (WebBrowserView)
  reference to the parent widget

#### UrlBar.__bookmarkChanged

__bookmarkChanged()

Private slot to handle bookmark or speed dial changes.

#### UrlBar.__browserUrlChanged

__browserUrlChanged(url)

Private slot to handle a URL change of the associated browser.

url (QUrl)
  new URL of the browser

#### UrlBar.__checkBookmark

__checkBookmark()

Private slot to check the current URL for the bookmarked state.

#### UrlBar.__loadFinished

__loadFinished(ok)

Private slot to set some data after the page was loaded.

ok (bool)
  flag indicating a successful load

#### UrlBar.__loadProgress

__loadProgress(progress)

Private slot to track the load progress.

progress (int)
  load progress in percent

#### UrlBar.__loadStarted

__loadStarted()

Private slot to perform actions before the page is loaded.

#### UrlBar.__rssTriggered

__rssTriggered()

Private slot to handle clicking the RSS icon.

#### UrlBar.__setRssButton

__setRssButton()

Private slot to show the RSS button.

#### UrlBar.__showBookmarkInfo

__showBookmarkInfo()

Private slot to show a dialog with some bookmark info.

#### UrlBar.__showThreatInfo

__showThreatInfo(pos)

Private slot to show the threat info widget.

pos (QPoint)
  position to show the info at

#### UrlBar.__sslConfigurationChanged

__sslConfigurationChanged()

Private slot to handle a change of the associated web page SSL configuration.

#### UrlBar.browser

browser()

Public method to get the associated browser.

Return:
  reference to the associated browser

Return Type:
  WebBrowserView

#### UrlBar.dragEnterEvent

dragEnterEvent(evt)

Protected method to handle drag enter events.

evt (QDragEnterEvent)
  reference to the drag enter event

#### UrlBar.dropEvent

dropEvent(evt)

Protected method to handle drop events.

evt (QDropEvent)
  reference to the drop event

#### UrlBar.focusOutEvent

focusOutEvent(evt)

Protected method to handle focus out event.

evt (QFocusEvent)
  reference to the focus event

#### UrlBar.keyPressEvent

keyPressEvent(evt)

Protected method to handle key presses.

evt (QKeyEvent)
  reference to the key press event

#### UrlBar.mouseDoubleClickEvent

mouseDoubleClickEvent(evt)

Protected method to handle mouse double click events.

evt (QMouseEvent)
  reference to the mouse event

#### UrlBar.mousePressEvent

mousePressEvent(evt)

Protected method called by a mouse press event.

evt (QMouseEvent)
  reference to the mouse event

#### UrlBar.preferencesChanged

preferencesChanged()

Public slot to handle a change of preferences.

#### UrlBar.setBrowser

setBrowser(browser)

Public method to set the browser connection.

browser (WebBrowserView)
  reference to the browser widget

Up